@@ -24,6 +24,8 @@
 |![Typescript Logo](https://docs.aws.amazon.com/cdk/api/latest/img/typescript32.png) Typescript|`@aws-solutions-constructs/aws-fargate-sqs`|
 |![Java Logo](https://docs.aws.amazon.com/cdk/api/latest/img/java32.png) Java|`software.amazon.awsconstructs.services.fargatesqs`|
 
+## Overview
+
 This AWS Solutions Construct implements an AWS Fargate service that can write to an Amazon SQS queue
 
 Here is a minimal deployable pattern definition:
@@ -92,7 +94,8 @@ new FargateToSqs(this, "test_construct", new FargateToSqsProps.Builder()
 |deployDeadLetterQueue?|boolean|Whether to create a secondary queue to be used as a dead letter queue. Defaults to `true`.|
 |deadLetterQueueProps?|[sqs.QueueProps](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-sqs.QueueProps.html)|Optional user-provided props to override the default props for the dead letter queue. Only used if the `deployDeadLetterQueue` property is set to true.|
 |maxReceiveCount?|integer|The number of times a message can be unsuccessfully dequeued before being moved to the dead letter queue. Defaults to `15`.|
-|queueUrlEnvironmentVariableName?|string|Optional Name for the SQS queue name environment variable set for the container.|
+|queueUrlEnvironmentVariableName?|string|Optional Name for the container environment variable set to the URL of the queue. Default: SQS_QUEUE_URL |
+|queueArnEnvironmentVariableName?|string|Optional Name for the container environment variable set to the arn of the queue. Default: SQS_QUEUE_ARN |
 |queuePermissions?|`string[]`|Optional queue permissions to grant to the Fargate service. One or more of the following may be specified: `Read`,`Write`. Default is `Write`|
 
 ## Pattern Properties
@@ -201,10 +204,10 @@ class FargateToSqs(
         :param fargate_service_props: Optional values to override default Fargate Task definition properties (fargate-defaults.ts). The construct will default to launching the service is the most isolated subnets available (precedence: Isolated, Private and Public). Override those and other defaults here. defaults - fargate-defaults.ts
         :param fargate_task_definition_props: -
         :param max_receive_count: The number of times a message can be unsuccessfully dequeued before being moved to the dead-letter queue. Default: - required field if deployDeadLetterQueue=true.
-        :param queue_arn_environment_variable_name: Optional Name for the SQS queue ARN environment variable to set for the container. Default: - None
+        :param queue_arn_environment_variable_name: Optional Name for the container environment variable set to the arn of the queue. Default: - SQS_QUEUE_ARN
         :param queue_permissions: Optional queue permissions to grant to the Fargate service. One or more of the following may be specified: ``Read``,``Write``. Default is ``Write`` Default: - Write
         :param queue_props: Optional user-provided props to override the default props for the SQS queue. Default: - Default props are used
-        :param queue_url_environment_variable_name: Optional Name for the SQS queue name environment variable to set for the container. Default: - None
+        :param queue_url_environment_variable_name: Optional Name for the container environment variable set to the URL of the queue. Default: - SQS_QUEUE_URL
         :param vpc_props: Optional custom properties for a VPC the construct will create. This VPC will be used by the new Fargate service the construct creates (that's why targetGroupProps can't include a VPC). Providing both this and existingVpc is an error. An SQS Interface endpoint will be included in this VPC. Default: - none
         '''
         props = FargateToSqsProps(
@@ -321,10 +324,10 @@ class FargateToSqsProps:
         :param fargate_service_props: Optional values to override default Fargate Task definition properties (fargate-defaults.ts). The construct will default to launching the service is the most isolated subnets available (precedence: Isolated, Private and Public). Override those and other defaults here. defaults - fargate-defaults.ts
         :param fargate_task_definition_props: -
         :param max_receive_count: The number of times a message can be unsuccessfully dequeued before being moved to the dead-letter queue. Default: - required field if deployDeadLetterQueue=true.
-        :param queue_arn_environment_variable_name: Optional Name for the SQS queue ARN environment variable to set for the container. Default: - None
+        :param queue_arn_environment_variable_name: Optional Name for the container environment variable set to the arn of the queue. Default: - SQS_QUEUE_ARN
         :param queue_permissions: Optional queue permissions to grant to the Fargate service. One or more of the following may be specified: ``Read``,``Write``. Default is ``Write`` Default: - Write
         :param queue_props: Optional user-provided props to override the default props for the SQS queue. Default: - Default props are used
-        :param queue_url_environment_variable_name: Optional Name for the SQS queue name environment variable to set for the container. Default: - None
+        :param queue_url_environment_variable_name: Optional Name for the container environment variable set to the URL of the queue. Default: - SQS_QUEUE_URL
         :param vpc_props: Optional custom properties for a VPC the construct will create. This VPC will be used by the new Fargate service the construct creates (that's why targetGroupProps can't include a VPC). Providing both this and existingVpc is an error. An SQS Interface endpoint will be included in this VPC. Default: - none
         '''
         if isinstance(cluster_props, dict):
@@ -508,9 +511,9 @@ class FargateToSqsProps:
 
     @builtins.property
     def queue_arn_environment_variable_name(self) -> typing.Optional[builtins.str]:
-        '''Optional Name for the SQS queue ARN environment variable to set for the container.
+        '''Optional Name for the container environment variable set to the arn of the queue.
 
-        :default: - None
+        :default: - SQS_QUEUE_ARN
         '''
         result = self._values.get("queue_arn_environment_variable_name")
         return typing.cast(typing.Optional[builtins.str], result)
@@ -537,9 +540,9 @@ class FargateToSqsProps:
 
     @builtins.property
     def queue_url_environment_variable_name(self) -> typing.Optional[builtins.str]:
-        '''Optional Name for the SQS queue name environment variable to set for the container.
+        '''Optional Name for the container environment variable set to the URL of the queue.
 
-        :default: - None
+        :default: - SQS_QUEUE_URL
         '''
         result = self._values.get("queue_url_environment_variable_name")
         return typing.cast(typing.Optional[builtins.str], result)
